==> DyWorld_0.8.6.zip: DyWorld_0.8.6/data/intermediate-list.lua <==
-- all intermediates here, tiered, and with real names
-- Tier 1 and 2 are available from start or unlocked after first research

--------------------------- Tier 1 ---------------------------------
"raw-fish" = Raw Fish
"stone-brick" = Stone Bricks
"chitin" = Chitin
"acorn" = Wood Seeds / Acorn
"sand" = Sand
"stone-gear-wheel" = Stone Gear Wheel
"stone-plate" = Stone Plate
"stone" = Stone
"coal" = Coal
"wood" = Wood
"simple-control-board" = Circuit for this tier

--------------------------- Tier 2 ---------------------------------
"glass" = Glass
"rotor" = Rotor
"wheat" = Wheat
"carrot" = Carrot
"obsidian" = Obsidian
"solar-cell" = Solar Cell
"filter-empty" = Empty Filter
"blade" = Blade (used in rotors)
"resin" = Resin
"iron-stick" = Iron Stick
"iron-gear-wheel" = Iron Gear
"iron-plate" = Iron Plate
"copper-plate" = Copper Plate
"copper-cable" = Copper Cable
"nickel-stick" = Nickel Stick
"nickel-plate" = Nickel Plate
"nickel-cable" = Nickel Cable
"nickel-gear-wheel" = Nickel Gear
"silver-stick" = Silver Stick
"silver-plate" = Silver Plate
"tin-cable" = Tin Cable
"tin-plate" = Tin Plate
"tin-gear-wheel" = Tin Gear
"basic-control-board" = Circuit for this tier

--------------------------- Tier 3 ---------------------------------
"red-wire" = Red Wires
"concrete" = Concrete
"green-wire" = Green Wires
"engine-unit" = Engine Unit
"battery" = Battery
"flying-robot-frame" = Flying robot frame
"plastic-bar" = Plastic
"sulfur" = Sulfur
"gunpowder" = Gunpowder
"frame" = Frame
"heater" = Heater
"gearbox" = Gearbox
"coil" = Coil
"battery-pack" = Battery Pack
"rubber" = Rubber
"steel-plate" = Steel Plate
"steel-stick" = Steel Stick
"steel-gear-wheel" = Steel Gear
"gold-stick" = Gold Stick
"gold-plate" = Gold Plate
"gold-cable" = Gold Cable
"bronze-stick" = Bronze Stick
"bronze-plate" = Bronze Plate
"bronze-cable" = Bronze Cable
"bronze-gear-wheel" = Bronze Gear
"lead-stick" = Lead Stick
"lead-plate" = Lead Plate
"lead-gear-wheel" = Lead Gear
"electronic-control-board" = Circuit for this tier

--------------------------- Tier 4 ---------------------------------
"empty-barrel" = Emty Barrels
"electric-engine-unit" = Electric Engine Unit
"explosives" = Explosive
"low-density-structure" = Low Density Structure
"solid-fuel" = Solid Fuel
"rocket-fuel" = Rocket Fuel
"rocket-control-unit" = Rocket Control Unit
"rocket-part" = Rocket Part
"housing" = Housing Unit
"intake" = Intake
"cobalt-stick" = Cobalt Stick
"cobalt-plate" = Cobalt Plate
"cobalt-cable" = Cobalt Cable
"cobalt-gear-wheel" = Cobalt Gear
"invar-stick" = Invar Stick
"invar-plate" = Invar Plate
"invar-cable" = Invar Cable
"invar-gear-wheel" = Invar Gear
"electrum-stick" = Electrum Stick
"electrum-plate" = Electrum Plate
"electrum-cable" = Electrum Cable
"advanced-control-board" = Circuit for this tier

--------------------------- Tier 5 ---------------------------------
"nuclear-fuel" = Nuclear Fuel
"satellite" = Satellite
"uranium-235" = Uranium 235
"uranium-238" = Uranium 238
"uranium-fuel-cell" = Uranium Fuel Cell
"used-up-uranium-fuel-cell" = Used up Fuel Cell
"logistic-unit" = Logistical Unit
"diamond" = Diamond
"stainless-steel-stick" = Stainless Steel Stick
"stainless-steel-plate" = Stainless Steel Plate
"stainless-steel-gear-wheel" = Stainless Steel Gear
"arditium-gear-wheel" =  Arditium Gear
"arditium-plate" = Arditium Plate
"tough-control-board" = Circuit for this tier

--------------------------- Tier 6 ---------------------------------
"controller" = Controller
"tungsten-stick" = Tungsten Stick
"tungsten-plate" = Tungsten Plate
"tungsten-gear-wheel" =  Tungsten Gear
"titanium-stick" = Titanium Stick
"titanium-plate" = Titanium Plate
"titanium-cable" = Titanium Cable
"titanium-gear-wheel" =  Titanium Gear
"processing-control-board" = Circuit for this tier

--------------------------- Tier 7 ---------------------------------
"arditium-tungstenate-plate" = Arditium-Tungstenate Plate
"arditium-tungstenate-stick" = Arditium-Tungstenate Stick
"arditium-tungstenate-gear-wheel" =  Arditium-Tungstenate Gear
"electranium-stick" = Electranium Stick
"electranium-plate" = Electranium Plate
"electranium-cable" = Electranium Cable
"logic-control-board" = Circuit for this tier

--------------------------- Tier 8 ---------------------------------
"tungstvar-stick" = Tungstvar Stick
"tungstvar-plate" = Tungstvar Plate
"super-control-board" = Circuit for this tier

--------------------------- Tier 9 ---------------------------------
"neutronium-stick" = Neutronium Stick
"neutronium-plate" = Neutronium Plate
"extreme-control-board" = Circuit for this tier

--------------------------- Tier 10 --------------------------------
"neutrobaltium-stick" = Neutrobaltium Stick
"neutrobaltium-plate" = Neutrobaltium Plate
"neutrobaltium-cable" = Neutrobaltium Cable
"neutrobaltium-gear-wheel" =  Neutrobaltium Gear
"quantum-control-board" = Circuit for this tier

==> DyWorld_0.9.2.zip: DyWorld_0.9.2/data/intermediate-list.lua <==
-- all intermediates here, tiered, and with real names
-- Tier 1 and 2 are available from start or unlocked after first research

--------------------------- Tier 1 ---------------------------------
"raw-fish" = Raw Fish
"stone-brick" = Stone Bricks
"chitin" = Chitin
"acorn" = Wood Seeds / Acorn
"sand" = Sand
"stone-gear-wheel" = Stone Gear Wheel
"stone-plate" = Stone Plate
"stone" = Stone
"coal" = Coal
"wood" = Wood
"simple-control-board" = Circuit for this tier
"simple-motor" = Motor for this tier

--------------------------- Tier 2 ---------------------------------
"glass" = Glass
"rotor" = Rotor
"wheat" = Wheat
"carrot" = Carrot
"obsidian" = Obsidian
"solar-cell" = Solar Cell
"filter-empty" = Empty Filter
"blade" = Blade (used in rotors)
"resin" = Resin
"iron-stick" = Iron Stick
"iron-gear-wheel" = Iron Gear
"iron-plate" = Iron Plate
"copper-plate" = Copper Plate
"copper-cable" = Copper Cable
"nickel-stick" = Nickel Stick
"nickel-plate" = Nickel Plate
"nickel-cable" = Nickel Cable
"nickel-gear-wheel" = Nickel Gear
"silver-stick" = Silver Stick
"silver-plate" = Silver Plate
"tin-cable" = Tin Cable
"tin-plate" = Tin Plate
"tin-gear-wheel" = Tin Gear
"basic-control-board" = Circuit for this tier
"turret-barrel" = Turret Barrel
"turret-base-2x2" = Turret Base 2 x 2

--------------------------- Tier 3 ---------------------------------
"red-wire" = Red Wires
"concrete" = Concrete
"green-wire" = Green Wires
"battery" = Battery
"flying-robot-frame" = Flying robot frame
"plastic-bar" = Plastic
"sulfur" = Sulfur
"gunpowder" = Gunpowder
"frame" = Frame
"heater" = Heater
"gearbox" = Gearbox
"coil" = Coil
"battery-pack" = Battery Pack
"rubber" = Rubber
"steel-plate" = Steel Plate
"steel-stick" = Steel Stick
"steel-gear-wheel" = Steel Gear
"gold-stick" = Gold Stick
"gold-plate" = Gold Plate
"gold-cable" = Gold Cable
"bronze-stick" = Bronze Stick
"bronze-plate" = Bronze Plate
"bronze-cable" = Bronze Cable
"bronze-gear-wheel" = Bronze Gear
"lead-stick" = Lead Stick
"lead-plate" = Lead Plate
"lead-gear-wheel" = Lead Gear
"electronic-control-board" = Circuit for this tier
"electronic-motor" = Motor for this tier
"turret-base-3x3" = Turret Base 3 x 3

--------------------------- Tier 4 ---------------------------------
"empty-barrel" = Emty Barrels
"explosives" = Explosive
"low-density-structure" = Low Density Structure
"solid-fuel" = Solid Fuel
"rocket-fuel" = Rocket Fuel
"rocket-control-unit" = Rocket Control Unit
"rocket-part" = Rocket Part
"housing" = Housing Unit
"intake" = Intake
"cobalt-stick" = Cobalt Stick
"cobalt-plate" = Cobalt Plate
"cobalt-cable" = Cobalt Cable
"cobalt-gear-wheel" = Cobalt Gear
"invar-stick" = Invar Stick
"invar-plate" = Invar Plate
"invar-cable" = Invar Cable
"invar-gear-wheel" = Invar Gear
"electrum-stick" = Electrum Stick
"electrum-plate" = Electrum Plate
"electrum-cable" = Electrum Cable
"advanced-control-board" = Circuit for this tier
"turret-base-5x5" = Turret Base 5 x 5

--------------------------- Tier 5 ---------------------------------
"nuclear-fuel" = Nuclear Fuel
"satellite" = Satellite
"uranium-235" = Uranium 235
"uranium-238" = Uranium 238
"uranium-fuel-cell" = Uranium Fuel Cell
"used-up-uranium-fuel-cell" = Used up Fuel Cell
"logistic-unit" = Logistical Unit
"diamond" = Diamond
"stainless-steel-stick" = Stainless Steel Stick
"stainless-steel-plate" = Stainless Steel Plate
"stainless-steel-gear-wheel" = Stainless Steel Gear
"arditium-gear-wheel" =  Arditium Gear
"arditium-plate" = Arditium Plate
"tough-control-board" = Circuit for this tier
"tough-motor" = Motor for this tier

--------------------------- Tier 6 ---------------------------------
"controller" = Controller
"tungsten-stick" = Tungsten Stick
"tungsten-plate" = Tungsten Plate
"tungsten-gear-wheel" =  Tungsten Gear
"titanium-stick" = Titanium Stick
"argonium-fuel-cell" = Argonium Fuel Cell
"titanium-plate" = Titanium Plate
"titanium-cable" = Titanium Cable
"titanium-gear-wheel" =  Titanium Gear
"processing-control-board" = Circuit for this tier

--------------------------- Tier 7 ---------------------------------
"arditium-tungstenate-plate" = Arditium-Tungstenate Plate
"arditium-tungstenate-stick" = Arditium-Tungstenate Stick
"arditium-tungstenate-gear-wheel" =  Arditium-Tungstenate Gear
"electranium-stick" = Electranium Stick
"electranium-plate" = Electranium Plate
"electranium-cable" = Electranium Cable
"logic-control-board" = Circuit for this tier
"logic-motor" = Motor for this tier

--------------------------- Tier 8 ---------------------------------
"tungstvar-stick" = Tungstvar Stick
"tungstvar-plate" = Tungstvar Plate
"super-control-board" = Circuit for this tier

--------------------------- Tier 9 ---------------------------------
"neutronium-stick" = Neutronium Stick
"neutronium-plate" = Neutronium Plate
"extreme-control-board" = Circuit for this tier
"extreme-motor" = Motor for this tier

--------------------------- Tier 10 --------------------------------
"neutrobaltium-stick" = Neutrobaltium Stick
"neutrobaltium-plate" = Neutrobaltium Plate
"neutrobaltium-cable" = Neutrobaltium Cable
"neutrobaltium-gear-wheel" =  Neutrobaltium Gear
"quantum-control-board" = Circuit for this tier
